@@ -197,10 +197,10 @@ class AddServerCert (qt.QDialog):
         # move to center
         prim_screen = ClientObj.app.desktop().primaryScreen()
 
-        x = ClientObj.app.desktop().screenGeometry(prim_screen).width()/2 - \
-                                            self.sizeHint().width()/2
-        y = ClientObj.app.desktop().screenGeometry(prim_screen).height()/2 - \
-                                            self.sizeHint().height()/2
+        x = int(ClientObj.app.desktop().screenGeometry(prim_screen).width()/2 - \
+                                            self.sizeHint().width()/2)
+        y = int(ClientObj.app.desktop().screenGeometry(prim_screen).height()/2 - \
+                                            self.sizeHint().height()/2)
         self.move(x, y)
         self.setFixedSize(self.sizeHint())
 
